@@ -195,13 +195,13 @@ module RSpec
           expect(receiver.foo).to eq(:curly)
         end
 
-        it 'does not support other matchers', :unless => options.include?(:allow_other_matchers) do
+        it 'does not support other matchers', :skip => options.include?(:allow_other_matchers) do
           expect {
             wrapped.to eq(3)
           }.to raise_error(UnsupportedMatcherError)
         end
 
-        it 'does support inherited matchers', :unless => options.include?(:allow_other_matchers) do
+        it 'does support inherited matchers', :skip => options.include?(:allow_other_matchers) do
           receive_foo = Class.new(RSpec::Mocks::Matchers::Receive).new(:foo, nil)
           wrapped.to receive_foo
           receiver.foo
@@ -411,6 +411,56 @@ module RSpec
         # rubocop:enable Lint/StructNewOverride
       end
 
+      shared_examples "handles stubbed #is_a? cleanly for a single instance" do
+        let(:klass) do
+          Class.new do
+            def call_stubbed_method
+              is_a?(self.class)
+            end
+          end
+        end
+
+        let(:object) { klass.new }
+
+        it "safely checks that the instance can be proxied" do
+          stubbed_answer = double("stubbed on an instance")
+          target.to receive(:is_a?).and_return(stubbed_answer)
+          expect(object.call_stubbed_method).to eq(stubbed_answer)
+        end
+      end
+
+      shared_examples "handles stubbed #is_a? cleanly for any_instance_of" do
+        let(:superclass) { Class.new }
+
+        let(:klass) do
+          Class.new(superclass) do
+            def call_stubbed_method
+              is_a?(self.class)
+            end
+          end
+        end
+
+        context "the class under test" do
+          let(:stubbed_class) { klass }
+
+          it "safely checks that the instance can be proxied" do
+            stubbed_answer = double("stubbed on the class under test")
+            target.to receive(:is_a?).and_return(stubbed_answer)
+            expect(klass.new.call_stubbed_method).to eq(stubbed_answer)
+          end
+        end
+
+        context "the parent of the class under test" do
+          let(:stubbed_class) { superclass }
+
+          it "safely checks that the instance can be proxied" do
+            stubbed_answer = double("stubbed on the superclass")
+            target.to receive(:is_a?).and_return(stubbed_answer)
+            expect(klass.new.call_stubbed_method).to eq(stubbed_answer)
+          end
+        end
+      end
+
       describe "allow(...).to receive" do
         it_behaves_like "an expect syntax allowance" do
           let(:receiver) { double }
@@ -422,6 +472,9 @@ module RSpec
         it_behaves_like "handles frozen objects cleanly" do
           let(:target) { allow(object) }
         end
+        it_behaves_like "handles stubbed #is_a? cleanly for a single instance" do
+          let(:target) { allow(object) }
+        end
 
         context 'ordered with receive counts' do
           specify 'is not supported' do
@@ -486,6 +539,10 @@ module RSpec
         it_behaves_like "resets partial mocks of any instance cleanly" do
           let(:target) { allow_any_instance_of(klass) }
         end
+
+        it_behaves_like "handles stubbed #is_a? cleanly for any_instance_of" do
+          let(:target) { allow_any_instance_of(stubbed_class) }
+        end
       end
 
       describe "allow_any_instance_of(...).not_to receive" do
@@ -532,6 +589,9 @@ module RSpec
         it_behaves_like "handles frozen objects cleanly" do
           let(:target) { expect(object) }
         end
+        it_behaves_like "handles stubbed #is_a? cleanly for a single instance" do
+          let(:target) { allow(object) }
+        end
 
         context "ordered with receive counts" do
           let(:dbl) { double(:one => 1, :two => 2) }
@@ -631,6 +691,9 @@ module RSpec
         it_behaves_like "resets partial mocks of any instance cleanly" do
           let(:target) { expect_any_instance_of(klass) }
         end
+        it_behaves_like "handles stubbed #is_a? cleanly for any_instance_of" do
+          let(:target) { expect_any_instance_of(stubbed_class) }
+        end
       end
 
       describe "expect(...).not_to receive" do
